==> ejc-labor-impl-3.0.0-20221116.095757-17-sources.jar: com/ejianc/business/labor/bean/WorkRecordEntity.java <==
package com.ejianc.business.labor.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 用工记录
 * 
 * @author generator
 * 
 */
 @TableName("ejc_labor_work_record")
public class WorkRecordEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="worker_id")
    private Long workerId; // 劳务员工id


    @TableField(value="project_team_id")
    private Long projectTeamId; // 项目班组
    @TableField(value="project_team_name")
    private String projectTeamName; // 项目班组名称
    @TableField(value="project_team_inner_code")
    private String projectTeamInnerCode; // 项目班组innerCode
    @TableField(value="org_team_id")
    private String orgTeamId; // 公司班组
    @TableField(value="org_team_name")
    private String orgTeamName; // 公司班组名称
    @TableField(value="org_team_inner_code")
    private String orgTeamInnerCode; // 公司班组innerCode

    @TableField(value="team_id")
    private String teamId; // 劳务班组
    @TableField(value="team_name")
    private String teamName; // 劳务班组名称

    @TableField(value="name")
    private String name; // 姓名
    @TableField(value="id_card")
    private String idCard; // 身份证号
    @TableField(value="sex")
    private Integer sex; // 1-男，2-女
    @TableField(value="birth_date")
    private Date birthDate; // 出生日期
    @TableField(value="nation")
    private String nation; // 民族
    @TableField(value="phone")
    private String phone; // 手机号

    @TableField(value="bank_name")
    private String bankName; // 开户行
    @TableField(value="bank_account")
    private String bankAccount; // 银行账号
    @TableField(value="wages_type")
    private Integer wagesType; // 工资类型
    @TableField(value="wages_type_name")
    private String wagesTypeName; // 工资类型名称
    @TableField(value="wage")
    private BigDecimal wage; // 工价
    @TableField(value="province")
    private String province; // 省
    @TableField(value="city")
    private String city; // 市
    @TableField(value="area")
    private String area; // 省市
    @TableField(value="address")
    private String address; // 详细地址
    @TableField(value="last_project_id")
    private Long lastProjectId; // 最后更新的项目id
    @TableField(value="project_work_type")
    private Long projectWorkType; // 项目工种
    @TableField(value="project_work_type_name")
    private String projectWorkTypeName; // 项目工种名称
    @TableField(value="org_work_type")
    private String orgWorkType; // 公司工种
    @TableField(value="org_work_type_name")
    private String orgWorkTypeName; // 公司工种名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 项目部所属组织id
    @TableField(value="parent_org_name")
    private String parentOrgName; // 项目部所属组织
    @TableField(value="project_address")
    private String projectAddress; // 项目地址
    @TableField(value="last_flag")
    private Integer lastFlag; // 最新记录标志（1是0否）
    @TableField(value="source_flag")
    private Integer sourceFlag; // 来源（1自制-劳务进场单、2公司花名册、3邀请）自制/公司花名册/邀请
    @TableField(value="source_id")
    private Long sourceId; // 来源主键（劳务进场单id）
    @TableField(value="enter_exit_state")
    private Integer enterExitState; // 在场状态（1在场、0退场）
    @TableField(value="enter_date")
    private Date enterDate; // 进场日期
    @TableField(value="exit_date")
    private Date exitDate; // 退场日期
    @TableField(value="sub_contract_id")
    private Long subContractId; // 分包合同id
    @TableField(value="sub_contract_name")
    private String subContractName; // 分包合同
    @TableField(value="supplier_id")
    private Long supplierId; // 供应商ID
    @TableField(value="supplier_name")
    private String supplierName; // 供应商
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称

    @TableField(value="work_type")
    private String workType; // 工种
    @TableField(value="work_type_name")
    private String workTypeName; // 工种名称
    @TableField(value="team_inner_code")
    private String TeamInnerCode;// 班组innerCode

    public String getTeamInnerCode() {
        return TeamInnerCode;
    }

    public void setTeamInnerCode(String teamInnerCode) {
        TeamInnerCode = teamInnerCode;
    }

    public String getWorkType() {
        return workType;
    }

    public void setWorkType(String workType) {
        this.workType = workType;
    }

    public String getWorkTypeName() {
        return workTypeName;
    }

    public void setWorkTypeName(String workTypeName) {
        this.workTypeName = workTypeName;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public Long getWorkerId() {
        return workerId;
    }

    public void setWorkerId(Long workerId) {
        this.workerId = workerId;
    }
    public Long getProjectTeamId() {
        return projectTeamId;
    }

    public void setProjectTeamId(Long projectTeamId) {
        this.projectTeamId = projectTeamId;
    }
    public String getProjectTeamName() {
        return projectTeamName;
    }

    public void setProjectTeamName(String projectTeamName) {
        this.projectTeamName = projectTeamName;
    }
    public String getProjectTeamInnerCode() {
        return projectTeamInnerCode;
    }

    public void setProjectTeamInnerCode(String projectTeamInnerCode) {
        this.projectTeamInnerCode = projectTeamInnerCode;
    }
    public String getOrgTeamId() {
        return orgTeamId;
    }

    public void setOrgTeamId(String orgTeamId) {
        this.orgTeamId = orgTeamId;
    }
    public String getOrgTeamName() {
        return orgTeamName;
    }

    public void setOrgTeamName(String orgTeamName) {
        this.orgTeamName = orgTeamName;
    }
    public String getOrgTeamInnerCode() {
        return orgTeamInnerCode;
    }

    public void setOrgTeamInnerCode(String orgTeamInnerCode) {
        this.orgTeamInnerCode = orgTeamInnerCode;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public Integer getSex() {
        return sex;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }
    public Date getBirthDate() {
        return birthDate;
    }

    public void setBirthDate(Date birthDate) {
        this.birthDate = birthDate;
    }
    public String getNation() {
        return nation;
    }

    public void setNation(String nation) {
        this.nation = nation;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public String getTeamId() {
        return teamId;
    }

    public void setTeamId(String teamId) {
        this.teamId = teamId;
    }
    public String getTeamName() {
        return teamName;
    }

    public void setTeamName(String teamName) {
        this.teamName = teamName;
    }
    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    public String getBankAccount() {
        return bankAccount;
    }

    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }
    public Integer getWagesType() {
        return wagesType;
    }

    public void setWagesType(Integer wagesType) {
        this.wagesType = wagesType;
    }
    public String getWagesTypeName() {
        return wagesTypeName;
    }

    public void setWagesTypeName(String wagesTypeName) {
        this.wagesTypeName = wagesTypeName;
    }
    public BigDecimal getWage() {
        return wage;
    }

    public void setWage(BigDecimal wage) {
        this.wage = wage;
    }
    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }
    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public Long getLastProjectId() {
        return lastProjectId;
    }

    public void setLastProjectId(Long lastProjectId) {
        this.lastProjectId = lastProjectId;
    }
    public Long getProjectWorkType() {
        return projectWorkType;
    }

    public void setProjectWorkType(Long projectWorkType) {
        this.projectWorkType = projectWorkType;
    }
    public String getProjectWorkTypeName() {
        return projectWorkTypeName;
    }

    public void setProjectWorkTypeName(String projectWorkTypeName) {
        this.projectWorkTypeName = projectWorkTypeName;
    }
    public String getOrgWorkType() {
        return orgWorkType;
    }

    public void setOrgWorkType(String orgWorkType) {
        this.orgWorkType = orgWorkType;
    }
    public String getOrgWorkTypeName() {
        return orgWorkTypeName;
    }

    public void setOrgWorkTypeName(String orgWorkTypeName) {
        this.orgWorkTypeName = orgWorkTypeName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getProjectAddress() {
        return projectAddress;
    }

    public void setProjectAddress(String projectAddress) {
        this.projectAddress = projectAddress;
    }
    public Integer getLastFlag() {
        return lastFlag;
    }

    public void setLastFlag(Integer lastFlag) {
        this.lastFlag = lastFlag;
    }
    public Integer getSourceFlag() {
        return sourceFlag;
    }

    public void setSourceFlag(Integer sourceFlag) {
        this.sourceFlag = sourceFlag;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Integer getEnterExitState() {
        return enterExitState;
    }

    public void setEnterExitState(Integer enterExitState) {
        this.enterExitState = enterExitState;
    }
    public Date getEnterDate() {
        return enterDate;
    }

    public void setEnterDate(Date enterDate) {
        this.enterDate = enterDate;
    }
    public Date getExitDate() {
        return exitDate;
    }

    public void setExitDate(Date exitDate) {
        this.exitDate = exitDate;
    }
    public Long getSubContractId() {
        return subContractId;
    }

    public void setSubContractId(Long subContractId) {
        this.subContractId = subContractId;
    }
    public String getSubContractName() {
        return subContractName;
    }

    public void setSubContractName(String subContractName) {
        this.subContractName = subContractName;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-labor-impl-3.0.0-20221117.144517-23-sources.jar: com/ejianc/business/labor/bean/WorkRecordEntity.java <==
package com.ejianc.business.labor.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 用工记录
 * 
 * @author generator
 * 
 */
 @TableName("ejc_labor_work_record")
public class WorkRecordEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="worker_id")
    private Long workerId; // 劳务员工id


    @TableField(value="project_team_id")
    private Long projectTeamId; // 项目班组
    @TableField(value="project_team_name")
    private String projectTeamName; // 项目班组名称
    @TableField(value="project_team_inner_code")
    private String projectTeamInnerCode; // 项目班组innerCode
    @TableField(value="org_team_id")
    private String orgTeamId; // 公司班组
    @TableField(value="org_team_name")
    private String orgTeamName; // 公司班组名称
    @TableField(value="org_team_inner_code")
    private String orgTeamInnerCode; // 公司班组innerCode

    @TableField(value="team_id")
    private String teamId; // 劳务班组
    @TableField(value="team_name")
    private String teamName; // 劳务班组名称

    @TableField(value="name")
    private String name; // 姓名
    @TableField(value="id_card")
    private String idCard; // 身份证号
    @TableField(value="sex")
    private Integer sex; // 1-男，2-女
    @TableField(value="birth_date")
    private Date birthDate; // 出生日期
    @TableField(value="nation")
    private String nation; // 民族
    @TableField(value="phone")
    private String phone; // 手机号

    @TableField(value="bank_name")
    private String bankName; // 开户行
    @TableField(value="bank_account")
    private String bankAccount; // 银行账号
    @TableField(value="wages_type")
    private Integer wagesType; // 工资类型
    @TableField(value="wages_type_name")
    private String wagesTypeName; // 工资类型名称
    @TableField(value="wage")
    private BigDecimal wage; // 工价
    @TableField(value="province")
    private String province; // 省
    @TableField(value="city")
    private String city; // 市
    @TableField(value="area")
    private String area; // 省市
    @TableField(value="address")
    private String address; // 详细地址
    @TableField(value="last_project_id")
    private Long lastProjectId; // 最后更新的项目id
    @TableField(value="project_work_type")
    private Long projectWorkType; // 项目工种
    @TableField(value="project_work_type_name")
    private String projectWorkTypeName; // 项目工种名称
    @TableField(value="org_work_type")
    private String orgWorkType; // 公司工种
    @TableField(value="org_work_type_name")
    private String orgWorkTypeName; // 公司工种名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 项目部所属组织id
    @TableField(value="parent_org_name")
    private String parentOrgName; // 项目部所属组织
    @TableField(value="project_address")
    private String projectAddress; // 项目地址
    @TableField(value="last_flag")
    private Integer lastFlag; // 最新记录标志（1是0否）
    @TableField(value="source_flag")
    private Integer sourceFlag; // 来源（1自制-劳务进场单、2公司花名册、3邀请）自制/公司花名册/邀请
    @TableField(value="source_id")
    private Long sourceId; // 来源主键（劳务进场单id）
    @TableField(value="enter_exit_state")
    private Integer enterExitState; // 在场状态（1在场、0退场）
    @TableField(value="enter_date")
    private Date enterDate; // 进场日期
    @TableField(value="exit_date")
    private Date exitDate; // 退场日期
    @TableField(value="sub_contract_id")
    private Long subContractId; // 分包合同id
    @TableField(value="sub_contract_name")
    private String subContractName; // 分包合同
    @TableField(value="supplier_id")
    private Long supplierId; // 供应商ID
    @TableField(value="supplier_name")
    private String supplierName; // 供应商
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称

    @TableField(value="work_type")
    private String workType; // 工种
    @TableField(value="work_type_name")
    private String workTypeName; // 工种名称
    @TableField(value="team_inner_code")
    private String TeamInnerCode;// 班组innerCode
    @TableField(value="id_card_front_photo_flag")
    private Integer idCardFrontPhotoFlag; // 身份证正面照片状态：0-待校验，1-是，2-否，3-异常
    @TableField(value="id_card_front_photo_exceptional")
    private String idCardFrontPhotoExceptional; // 身份证正面异常信息
    @TableField(value="id_card_back_photo_flag")
    private Integer idCardBackPhotoFlag; // 身份证反面照片状态：0-待校验，1-是，2-否，3-异常
    @TableField(value="id_card_back_photo_exceptional")
    private String idCardBackPhotoExceptional; // 身份证反面异常信息
    @TableField(value="face_photo_flag")
    private Integer facePhotoFlag; // 人脸采集状态：0-待校验，1-是，2-否，3-异常
    @TableField(value="face_photo_exceptional")
    private String facePhotoExceptional; // 人脸采集异常信息
    @TableField(value="id_card_name")
    private String idCardName; // 身份证照片识别的姓名
    @TableField(value = "id_card_no")
    private String idCardNo; // 身份证照片识别的身份证号
    @TableField(value = "id_card_sex")
    private String idCardSex; // 身份证照片识别的性别，1-男，2-女
    @TableField(value = "id_card_birth_date")
    private String idCardBirthDate; // 身份证照片识别的出生年月
    @TableField(value = "id_card_nation")
    private String idCardNation; // 身份证照片识别的民族
    @TableField(value = "id_card_start_date")
    private String idCardStartDate; // 身份证照片识别的起始有效期
    @TableField(value = "id_card_end_date")
    private String idCardEndDate; // 身份证照片识别的截止有效期
    @TableField(value = "id_card_issue")
    private String idCardIssue; // 身份证照片识别的签发机关

    public Integer getIdCardFrontPhotoFlag() {
        return idCardFrontPhotoFlag;
    }

    public void setIdCardFrontPhotoFlag(Integer idCardFrontPhotoFlag) {
        this.idCardFrontPhotoFlag = idCardFrontPhotoFlag;
    }

    public String getIdCardFrontPhotoExceptional() {
        return idCardFrontPhotoExceptional;
    }

    public void setIdCardFrontPhotoExceptional(String idCardFrontPhotoExceptional) {
        this.idCardFrontPhotoExceptional = idCardFrontPhotoExceptional;
    }

    public Integer getIdCardBackPhotoFlag() {
        return idCardBackPhotoFlag;
    }

    public void setIdCardBackPhotoFlag(Integer idCardBackPhotoFlag) {
        this.idCardBackPhotoFlag = idCardBackPhotoFlag;
    }

    public String getIdCardBackPhotoExceptional() {
        return idCardBackPhotoExceptional;
    }

    public void setIdCardBackPhotoExceptional(String idCardBackPhotoExceptional) {
        this.idCardBackPhotoExceptional = idCardBackPhotoExceptional;
    }

    public Integer getFacePhotoFlag() {
        return facePhotoFlag;
    }

    public void setFacePhotoFlag(Integer facePhotoFlag) {
        this.facePhotoFlag = facePhotoFlag;
    }

    public String getFacePhotoExceptional() {
        return facePhotoExceptional;
    }

    public void setFacePhotoExceptional(String facePhotoExceptional) {
        this.facePhotoExceptional = facePhotoExceptional;
    }

    public String getIdCardName() {
        return idCardName;
    }

    public void setIdCardName(String idCardName) {
        this.idCardName = idCardName;
    }

    public String getIdCardNo() {
        return idCardNo;
    }

    public void setIdCardNo(String idCardNo) {
        this.idCardNo = idCardNo;
    }

    public String getIdCardSex() {
        return idCardSex;
    }

    public void setIdCardSex(String idCardSex) {
        this.idCardSex = idCardSex;
    }

    public String getIdCardBirthDate() {
        return idCardBirthDate;
    }

    public void setIdCardBirthDate(String idCardBirthDate) {
        this.idCardBirthDate = idCardBirthDate;
    }

    public String getIdCardNation() {
        return idCardNation;
    }

    public void setIdCardNation(String idCardNation) {
        this.idCardNation = idCardNation;
    }

    public String getIdCardStartDate() {
        return idCardStartDate;
    }

    public void setIdCardStartDate(String idCardStartDate) {
        this.idCardStartDate = idCardStartDate;
    }

    public String getIdCardEndDate() {
        return idCardEndDate;
    }

    public void setIdCardEndDate(String idCardEndDate) {
        this.idCardEndDate = idCardEndDate;
    }

    public String getIdCardIssue() {
        return idCardIssue;
    }

    public void setIdCardIssue(String idCardIssue) {
        this.idCardIssue = idCardIssue;
    }

    public String getTeamInnerCode() {
        return TeamInnerCode;
    }

    public void setTeamInnerCode(String teamInnerCode) {
        TeamInnerCode = teamInnerCode;
    }

    public String getWorkType() {
        return workType;
    }

    public void setWorkType(String workType) {
        this.workType = workType;
    }

    public String getWorkTypeName() {
        return workTypeName;
    }

    public void setWorkTypeName(String workTypeName) {
        this.workTypeName = workTypeName;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public Long getWorkerId() {
        return workerId;
    }

    public void setWorkerId(Long workerId) {
        this.workerId = workerId;
    }
    public Long getProjectTeamId() {
        return projectTeamId;
    }

    public void setProjectTeamId(Long projectTeamId) {
        this.projectTeamId = projectTeamId;
    }
    public String getProjectTeamName() {
        return projectTeamName;
    }

    public void setProjectTeamName(String projectTeamName) {
        this.projectTeamName = projectTeamName;
    }
    public String getProjectTeamInnerCode() {
        return projectTeamInnerCode;
    }

    public void setProjectTeamInnerCode(String projectTeamInnerCode) {
        this.projectTeamInnerCode = projectTeamInnerCode;
    }
    public String getOrgTeamId() {
        return orgTeamId;
    }

    public void setOrgTeamId(String orgTeamId) {
        this.orgTeamId = orgTeamId;
    }
    public String getOrgTeamName() {
        return orgTeamName;
    }

    public void setOrgTeamName(String orgTeamName) {
        this.orgTeamName = orgTeamName;
    }
    public String getOrgTeamInnerCode() {
        return orgTeamInnerCode;
    }

    public void setOrgTeamInnerCode(String orgTeamInnerCode) {
        this.orgTeamInnerCode = orgTeamInnerCode;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public Integer getSex() {
        return sex;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }
    public Date getBirthDate() {
        return birthDate;
    }

    public void setBirthDate(Date birthDate) {
        this.birthDate = birthDate;
    }
    public String getNation() {
        return nation;
    }

    public void setNation(String nation) {
        this.nation = nation;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public String getTeamId() {
        return teamId;
    }

    public void setTeamId(String teamId) {
        this.teamId = teamId;
    }
    public String getTeamName() {
        return teamName;
    }

    public void setTeamName(String teamName) {
        this.teamName = teamName;
    }
    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    public String getBankAccount() {
        return bankAccount;
    }

    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }
    public Integer getWagesType() {
        return wagesType;
    }

    public void setWagesType(Integer wagesType) {
        this.wagesType = wagesType;
    }
    public String getWagesTypeName() {
        return wagesTypeName;
    }

    public void setWagesTypeName(String wagesTypeName) {
        this.wagesTypeName = wagesTypeName;
    }
    public BigDecimal getWage() {
        return wage;
    }

    public void setWage(BigDecimal wage) {
        this.wage = wage;
    }
    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }
    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public Long getLastProjectId() {
        return lastProjectId;
    }

    public void setLastProjectId(Long lastProjectId) {
        this.lastProjectId = lastProjectId;
    }
    public Long getProjectWorkType() {
        return projectWorkType;
    }

    public void setProjectWorkType(Long projectWorkType) {
        this.projectWorkType = projectWorkType;
    }
    public String getProjectWorkTypeName() {
        return projectWorkTypeName;
    }

    public void setProjectWorkTypeName(String projectWorkTypeName) {
        this.projectWorkTypeName = projectWorkTypeName;
    }
    public String getOrgWorkType() {
        return orgWorkType;
    }

    public void setOrgWorkType(String orgWorkType) {
        this.orgWorkType = orgWorkType;
    }
    public String getOrgWorkTypeName() {
        return orgWorkTypeName;
    }

    public void setOrgWorkTypeName(String orgWorkTypeName) {
        this.orgWorkTypeName = orgWorkTypeName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getProjectAddress() {
        return projectAddress;
    }

    public void setProjectAddress(String projectAddress) {
        this.projectAddress = projectAddress;
    }
    public Integer getLastFlag() {
        return lastFlag;
    }

    public void setLastFlag(Integer lastFlag) {
        this.lastFlag = lastFlag;
    }
    public Integer getSourceFlag() {
        return sourceFlag;
    }

    public void setSourceFlag(Integer sourceFlag) {
        this.sourceFlag = sourceFlag;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Integer getEnterExitState() {
        return enterExitState;
    }

    public void setEnterExitState(Integer enterExitState) {
        this.enterExitState = enterExitState;
    }
    public Date getEnterDate() {
        return enterDate;
    }

    public void setEnterDate(Date enterDate) {
        this.enterDate = enterDate;
    }
    public Date getExitDate() {
        return exitDate;
    }

    public void setExitDate(Date exitDate) {
        this.exitDate = exitDate;
    }
    public Long getSubContractId() {
        return subContractId;
    }

    public void setSubContractId(Long subContractId) {
        this.subContractId = subContractId;
    }
    public String getSubContractName() {
        return subContractName;
    }

    public void setSubContractName(String subContractName) {
        this.subContractName = subContractName;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
